pub fn set_path_materializer(
materializer: PathMaterializerFn,
) -> PathMaterializerGuardExpand description
Install a path materializer for the current thread.
Returns an RAII guard that restores the previous materializer on drop.
pub fn set_path_materializer(
materializer: PathMaterializerFn,
) -> PathMaterializerGuardInstall a path materializer for the current thread.
Returns an RAII guard that restores the previous materializer on drop.