pub struct BuiltinRegistry { /* private fields */ }Expand description
Registry of builtin functions accessible from the VM.
Implementations
Sourceimpl BuiltinRegistry
impl BuiltinRegistry
Sourcepub fn lookup(&self, name: &str) -> Option<u16>
pub fn lookup(&self, name: &str) -> Option<u16>
Look up a builtin by name, returning its index.
Sourcepub fn call(&self, index: u16, args: Vec<VMValue>) -> Result<VMValue, VMError>
pub fn call(&self, index: u16, args: Vec<VMValue>) -> Result<VMValue, VMError>
Call a builtin by index.
Sourcepub fn make_builtins_attrset(&self, interner: &mut Interner) -> VMValue
pub fn make_builtins_attrset(&self, interner: &mut Interner) -> VMValue
Build the builtins attribute set with all registered builtins.