pub struct Compiler { /* private fields */ }Expand description
Implementations
Sourceimpl Compiler
impl Compiler
Sourcepub fn compile_with_base_dir(
input: &str,
base_dir: PathBuf,
) -> Result<(Chunk, Interner), CompileError>
pub fn compile_with_base_dir( input: &str, base_dir: PathBuf, ) -> Result<(Chunk, Interner), CompileError>
Compile a Nix expression string into bytecode and an interner, resolving relative paths against the given base directory.
Compile using a shared interner and base directory. Used when importing files from within the VM so that symbol IDs are consistent with the VM’s interner.
Sourcepub fn compile_expression(
input: &str,
base_dir: &Path,
interner: Rc<RefCell<Interner>>,
) -> Result<Chunk, CompileError>
pub fn compile_expression( input: &str, base_dir: &Path, interner: Rc<RefCell<Interner>>, ) -> Result<Chunk, CompileError>
Compile a standalone expression string (used for lazy thunk compilation). The expression is parsed and compiled fresh with the given interner and base directory.